@@ -732,6 +732,15 @@ pub trait IsMenuItem<R: Runtime>: sealed::IsMenuItemBase {
 ///
 /// This trait is ONLY meant to be implemented internally by the crate.
 pub trait ContextMenu: sealed::ContextMenuBase + Send + Sync {
+  /// Get the popup [`HMENU`] for this menu.
+  ///
+  /// The returned [`HMENU`] is valid as long as the [`ContextMenu`] is.
+  ///
+  /// [`HMENU`]: https://learn.microsoft.com/en-us/windows/win32/winprog/windows-data-types#HMENU
+  #[cfg(windows)]
+  #[cfg_attr(docsrs, doc(cfg(windows)))]
+  fn hpopupmenu(&self) -> crate::Result<isize>;
+
   /// Popup this menu as a context menu on the specified window at the cursor position.
   fn popup<R: crate::Runtime>(&self, window: crate::Window<R>) -> crate::Result<()>;
 
